<?php

namespace EventPortal\Domain\Email;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Notification\NotificationData;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\View\View;

class PreviewEmail extends Mailable
{
    use Queueable, SerializesModels;

    /** @var EventEmail */
    public $email;

    /** @var NotificationData */
    public $data;

    /** @var User */
    public $recipient;

    public function __construct(EventEmail $email)
    {
        $this->email = $email;
        $this->data = new NotificationData();
        $this->data->setEvent($email->event);
        $this->recipient = $this->getPreviewRecipient();
    }

    public function build(): self
    {
        $emailView = $this->email->getNotificationKey();

        return $this->subject("[PREVIEW] {$this->email->subject}")
            ->view("EventPortal::email.{$emailView}")
            ->text("EventPortal::email.{$emailView}-plain");
    }

    public function render(): View
    {
        return view($this->build()->view, [
            'data' => (object) $this->data,
            'recipient' => $this->recipient,
        ]);
    }

    public function renderPlainText(): View
    {
        return view($this->build()->textView, [
            'data' => $this->data,
            'recipient' => $this->recipient,
        ]);
    }

    private function getPreviewRecipient(): User
    {
        return new User([
            'first_name' => '[Firstname]',
            'email' => 'test-address@example.com',
        ]);
    }
}
