<?php

namespace EventPortal\Tests\Feature\Delegate\Event;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Util\Notification\SystemNotification;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Notification;
use Spatie\Snapshots\MatchesSnapshots;

class ContactTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    /** @test */
    public function view_contact_page()
    {
        $delegate = factory(Delegate::class)->state('snapshot')->create();
        $event = factory(Event::class)->state('snapshot')->create();
        $event->delegates()->attach($delegate, ['status' => 'invited', 'pathway_id' => 1]);

        $this->assertMatchesJsonSnapshot(
            $this->actingAs($delegate->user)->get(route('contact.index', $event))->props()
        );
    }

    /** @test */
    public function submit_contact_form()
    {
        Notification::fake();

        $delegate = factory(Delegate::class)->state('snapshot')->create();
        $event = factory(Event::class)->create([
            'email' => 'event@email.com',
        ]);
        $event->delegates()->attach($delegate, ['status' => 'invited', 'pathway_id' => 1]);

        $this
            ->actingAs($delegate->user)
            ->followingRedirects()
            ->post(route('contact.store', $event), [
                'first_name' => 'First name',
                'last_name' => 'Last name',
                'email' => 'first@last.com',
                'subject' => 'The subject',
                'message' => 'The message',
            ]);

        Notification::assertSentTo(
            [$event],
            SystemNotification::class,
            static function (SystemNotification $notification) {
                return $notification->subject === 'The subject';
            }
        );
    }
}
