<?php

namespace EventPortal\Tests\Unit\Agenda\Actions;

use EventPortal\Domain\Agenda\Actions\CreateDefaultAgenda;
use EventPortal\Domain\Agenda\Actions\CreateSession;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Carbon;
use Illuminate\Validation\ValidationException;

class CreateSessionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_session_for_pathway()
    {
        $event = factory(Event::class)->create();
        $pathway = factory(Pathway::class)->state('default')->create([
            'event_id' => $event->id,
        ]);

        (new CreateDefaultAgenda)->execute($event, '2020-05-20');
        $agenda = Agenda::first();

        (new CreateSession)->execute($pathway, $agenda, [
            'session-name' => 'Lunch Break',
            'session-start-time' => '13:00',
            'session-end-time' => '13:30',
            'session-location' => 'Reception',
            'session-description' => 'Session description',
        ]);

        $session = Session::first();

        $this->assertEquals($pathway->id, $session->pathway->id);
        $this->assertEquals($agenda->id, $session->agenda->id);
    }

    /** @test **/
    public function cannot_create_session_that_completely_overlaps()
    {
        $event = factory(Event::class)->create();
        $pathway = factory(Pathway::class)->state('default')->create([
            'event_id' => $event->id,
        ]);

        (new CreateDefaultAgenda)->execute($event, '2020-05-20');
        $agenda = Agenda::first();

        $session = factory(Session::class)->create([
            'starting_at' => Carbon::parse('09:00:00'),
            'ending_at' => Carbon::parse('10:00:00'),
            'pathway_id' => $pathway->id,
        ]);

        try {
            (new CreateSession)->execute($session->pathway, $agenda, [
                'session-name' => 'Lunch Break',
                'session-start-time' => '08:00',
                'session-end-time' => '11:30',
                'session-location' => 'Reception',
                'session-description' => 'Session description',
            ]);
        } catch (ValidationException $exception) {
            $this->assertArrayHasKey('session-start-time', $exception->errors());
            $this->assertArrayHasKey('session-end-time', $exception->errors());

            return;
        }

        $this->fail('Validation exception was not thrown.');
    }
}
