<?php

namespace EventPortal\Tests\Unit\Handlers;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class CreateModelTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_save_model()
    {
        $payload = Payload::make(['name' => 'Hello World'])->withModel(new Event);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateModel()])
            ->thenReturn();

        $this->assertDatabaseHas('events', [
            'name' => 'Hello World',
        ]);
    }

    /** @test **/
    public function hydrated_model_is_added()
    {
        $payload = Payload::make(['name' => 'Hello World'])->withModel(new Event);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateModel])
            ->then(function ($payload) {
                $this->assertTrue($payload->getModel()->wasRecentlyCreated);
                $this->assertEquals(1, $payload->getModel()->id);
            });
    }
}
