<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Seeds\RoleSeeder;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Route;
use Spatie\Snapshots\MatchesSnapshots;

class AdminRenderTest extends TestCase
{
    use MatchesSnapshots, RefreshDatabase;

    public function setUp(): void
    {
        parent::setUp();
        $this->withoutMiddleware();

        $this->pageHeader = [
            "title" => "Dashboard",
            "description" => "A home page",
            "howToText" => 'Text that isn\'t null',
            "howToVideo" => null,
        ];

        config(['page-headers.admin.dashboard.index' => $this->pageHeader]);

        (new RoleSeeder())->run();
        $this->actingAsAdmin();
    }

    /** @test */
    public function can_include_table(): void
    {
        factory(Event::class)->create(['name' => 'Test Event']);

        $table = Table::make('event.index')
            ->query(Event::query()->isNotArchived())
            ->request(request())
            ->get();

        $viewdata = AdminRender::component('Some/Page')
            ->key('dashboard.index')
            ->withTable($table)
            ->getData();

        $this->assertMatchesJsonSnapshot(json_encode($viewdata));
    }

    /** @test */
    public function can_include_breadcrumbs(): void
    {
        Route::get('test')->name('test.index');
        Route::get('test-2/{id}')->name('test2.index');

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('test.index'))
            ->add('Event 1', route('test2.index', 1))
            ->get();

        $viewdata = AdminRender::component('Some/Page')
            ->key('dashboard.index')
            ->withBreadcrumbs($breadcrumbs)
            ->getData();


        $this->assertMatchesJsonSnapshot(json_encode($viewdata));
    }
}
